@@ -1,85 +1,74 @@
 # -*- coding: utf-8 -*-
 
-
-
 import aiohttp
 import asyncio
 from asyncpy.exceptions import InvalidRequestMethod
 from typing import Coroutine, Optional, Tuple
-from asyncpy.tools import check_logger,get_logger
+from asyncpy.tools import check_logger, get_logger
 from asyncpy.response import Response
 import async_timeout
-from inspect import iscoroutinefunction,getabsfile
+from inspect import iscoroutinefunction, getabsfile
 from asyncio.locks import Semaphore
 from types import AsyncGeneratorType
 import weakref
 import traceback
-
 from asyncpy import settings
 
 
-
-
 class Request(object):
-
     name = "Request"
 
-    if "DEFAULT_REQUEST_CONFIG" not in dir(settings):
-        DEFAULT_REQUEST_CONFIG = {}
-    else:
-        DEFAULT_REQUEST_CONFIG = settings.DEFAULT_REQUEST_CONFIG
+    REQUEST_CONFIG = settings.DEFAULT_REQUEST_CONFIG
 
-
-    REQUEST_CONFIG = DEFAULT_REQUEST_CONFIG
     REQUEST_CONFIG["RETRY_FUNC"] = Coroutine
     REQUEST_CONFIG["VALID"] = Coroutine
 
-
     METHOD = ["GET", "POST"]
 
-
     def __init__(self,
-                url: str,
-                method: str = "GET",*,
-                callback=None,encoding: Optional[str] = None,
-                headers: dict= None,
-                meta: dict = None,custom_settings: dict = None,
-                request_session=None,**aiohttp_kwargs):
+                 url: str,
+                 method: str = "GET", *,
+                 settings_attr=None,
+                 callback=None, encoding: Optional[str] = None,
+                 headers: dict = None,
+                 meta: dict = None, custom_settings: dict = None,
+                 request_session=None, **aiohttp_kwargs):
         self.url = url
         self.method = method.upper()
         self.custom_settings = None
 
         if self.method not in self.METHOD:
-            raise InvalidRequestMethod("%s method is not supported"%self.method)
+            raise InvalidRequestMethod("%s method is not supported" % self.method)
 
         self.callback = callback
         self.encoding = encoding
         self.headers = headers or {}
 
-        if "USER_AGENT" in dir(settings):
-            self.headers['User-Agent'] = settings.USER_AGENT
-
-
         self.meta = meta or {}
         self.request_session = request_session
-        self.request_settings = (
-            self.REQUEST_CONFIG if custom_settings is None else custom_settings
-        )
+
+        self.settings_attr = settings_attr or {}
+        if self.settings_attr and settings_attr.get('USER_AGENT'):
+            self.headers['User-Agent'] = settings_attr.get('USER_AGENT')
+        self.request_settings = self.REQUEST_CONFIG
+        if self.settings_attr and settings_attr.get('DEFAULT_REQUEST_CONFIG'):
+            self.request_settings = settings_attr.get('DEFAULT_REQUEST_CONFIG')
+        if custom_settings:
+            self.request_settings = custom_settings
+
         self.ssl = aiohttp_kwargs.pop("ssl", False)
         self.aiohttp_kwargs = aiohttp_kwargs
 
         self.close_request_session = False
 
         if custom_settings and custom_settings.get('LOG_FILE'):
-            LOG_FILE, LOG_LEVEL = custom_settings.get('LOG_FILE'),custom_settings.get('LOG_LEVEL','INFO')
-            self.logger = get_logger(name=self.name,filename=LOG_FILE,level=LOG_LEVEL)
+            LOG_FILE, LOG_LEVEL = custom_settings.get('LOG_FILE'), custom_settings.get('LOG_LEVEL', 'INFO')
+            self.logger = get_logger(name=self.name, filename=LOG_FILE, level=LOG_LEVEL)
         else:
             self.logger = check_logger(name=self.name)
 
         self.retry_times = self.request_settings.get("RETRIES", 3)
 
-
-
     @property
     def current_request_session(self):
         if self.request_session is None:
@@ -87,7 +76,6 @@ class Request(object):
             self.close_request_session = True
         return self.request_session
 
-
     async def fetch(self, delay=True) -> Response:
 
         """Fetch all the information by using aiohttp"""
@@ -134,7 +122,7 @@ class Request(object):
             await self._close_request()
 
     async def fetch_callback(
-        self, sem: Semaphore
+            self, sem: Semaphore
     ) -> Tuple[AsyncGeneratorType, Response]:
         """
         Request the target url and then call the callback function
@@ -157,12 +145,10 @@ class Request(object):
             callback_result = None
         return callback_result, response
 
-
     async def _close_request(self):
         if self.close_request_session:
             await self.request_session.close()
 
-
     async def _make_request(self):
         """通过 aiohttp 发起请求"""
         self.logger.info(f"<{self.method}: {self.url}>")
@@ -177,7 +163,6 @@ class Request(object):
         resp = await request_func
         return resp
 
-
     async def _retry(self, error_msg):
         """Manage request"""
         if self.retry_times > 0:
