@@ -17,7 +17,7 @@ from asyncpy.exceptions import SpiderHookError
 from asyncpy.middleware import Middleware
 from asyncpy.request import Request
 from asyncpy.response import Response
-from asyncpy.tools import check_logger,get_logger
+from asyncpy.tools import check_logger,get_logger,get_attrs
 import importlib
 import sys
 
@@ -102,7 +102,7 @@ class Spider(SpiderHook):
     """
     name = None
     custom_settings = None
-    settings = None
+    settings_attr = None
     # Default values passing to each request object. Not implemented yet.
     headers: dict = None
     meta: dict = None
@@ -178,13 +178,15 @@ class Spider(SpiderHook):
 
         # async queue as a producer
         self.request_queue = asyncio.Queue()
-
-        if not self.settings:
+        if not self.settings_attr:
             from asyncpy import settings
-        global settings
+        else:
+            self.settings_attr = get_attrs(self.settings_attr)
+            self.concurrency = self.settings_attr.get('CONCURRENT_REQUESTS')
         if not self.concurrency:
-            self.concurrency =  settings.CONCURRENT_REQUESTS
-        print(self.concurrency)
+            self.concurrency = settings.CONCURRENT_REQUESTS
+
+
         # semaphore, used for concurrency control
         self.sem = asyncio.Semaphore(self.concurrency)
 
@@ -369,15 +371,6 @@ class Spider(SpiderHook):
         **spider_kwargs):
 
 
-        #print(getabsfile(cls))
-        # modles = importlib.import_module(cls.name)
-        # print(modles)
-
-        # global setting
-        # setting = modles.setting
-
-
-
         # if 'MIDDLEWARE' in dir(setting):
         #     mw_list = setting.MIDDLEWARE
         #     if mw_list:
@@ -387,7 +380,6 @@ class Spider(SpiderHook):
         #             middleware_path = getabsfile(setting).replace('setting.py',clast+'.py')
 
 
-
         # pipelines_list = []
         # if 'PIPELINES' in dir(setting):
         #     pl_list = setting.PIPELINES
@@ -526,6 +518,7 @@ class Spider(SpiderHook):
         return Request(
             url=url,
             method=method,
+            settings_attr = self.settings_attr,
             callback=callback,
             encoding=encoding,
             headers=headers,
@@ -566,13 +559,6 @@ class Spider(SpiderHook):
                     *self.worker_tasks, return_exceptions=True
                 )
                 for task_result in results:
-                    if "CLOSESPIDER_TIMEOUT" in dir(settings):
-                        date1 = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
-                        date1 = datetime.strptime(date1, "%Y-%m-%d %H:%M:%S")
-                        if (date1 - date2).total_seconds()>settings.CLOSESPIDER_TIMEOUT:
-                            self.logger.warning("<Running time over ClOSE_TIMEOUT,So Spider Closed>")
-                            break
-
                     if not isinstance(task_result, RuntimeError) and task_result:
                         callback_results, response = task_result
                         if isinstance(callback_results, AsyncGeneratorType):
